import { cut } from 'jieba-wasm';

function segmentParagraphs(text) {
  return text.split(/[\f\n\r\t\v]+/gm).map((s) => s.trim()).filter((w) => !!w);
}

function segmentSentences(text, options) {
  switch (options.lang) {
    case "zh":
      return text.replace(/([。；？！])/gm, "$1\r\n").split(/[\f\n\r\t\v]+/gm).map((s) => s.trim()).filter((w) => !!w);
    default:
      return text.replace(/([.;?!])/gm, "$1\r\n").split(/[\f\n\r\t\v]+/gm).map((s) => s.trim()).filter((w) => !!w);
  }
}

function segmentPhrases(text, options) {
  switch (options.lang) {
    case "zh":
      return text.replace(/([，。；：？！])/gm, "$1\r\n").split(/[\f\n\r\t\v]+/gm).map((s) => s.trim()).filter((w) => !!w);
    default:
      return text.replace(/([,.;:?!])/gm, "$1\r\n").split(/[\f\n\r\t\v]+/gm).map((s) => s.trim()).filter((w) => !!w);
  }
}

function segmentWords(text, options) {
  switch (options.lang) {
    case "zh":
      return cut(text, true);
    default:
      return text.replace(/([\x20,.;:?!])/gm, "\r\n$1\r\n").split(/[\f\n\r\t\v]+/gm).map((s) => s.trim()).filter((w) => !!w);
  }
}

function createSegmentation(text, options) {
  const { lang } = options;
  switch (options.segmentation) {
    case "paragraphs":
      return segmentParagraphs(text);
    case "sentences":
      return segmentSentences(text, {
        lang
      });
    case "phrases":
      return segmentPhrases(text, {
        lang
      });
    case "words":
      return segmentWords(text, {
        lang
      });
  }
}

export { createSegmentation, segmentParagraphs, segmentPhrases, segmentSentences, segmentWords };
